@@ -2,14 +2,13 @@ package Bot::IRC::X::Reminder;
 # ABSTRACT: Bot::IRC plugin for scheduling reminders
 
 use 5.014;
-use strict;
-use warnings;
+use exact;
 
 use DateTime;
 use DateTime::Duration;
 use Time::Crontab;
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -162,10 +161,10 @@ Bot::IRC::X::Reminder - Bot::IRC plugin for scheduling reminders
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
-=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Reminder.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC-X-Reminder)
-[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC-X-Reminder/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Reminder)
+=for markdown [![test](https://github.com/gryphonshafer/Bot-IRC-X-Reminder/workflows/test/badge.svg)](https://github.com/gryphonshafer/Bot-IRC-X-Reminder/actions?query=workflow%3Atest)
+[![codecov](https://codecov.io/gh/gryphonshafer/Bot-IRC-X-Reminder/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Bot-IRC-X-Reminder)
 
 =head1 SYNOPSIS
 
@@ -263,23 +262,15 @@ L<GitHub|https://github.com/gryphonshafer/Bot-IRC-X-Reminder>
 
 =item *
 
-L<CPAN|http://search.cpan.org/dist/Bot-IRC-X-Reminder>
-
-=item *
-
 L<MetaCPAN|https://metacpan.org/pod/Bot::IRC::X::Reminder>
 
 =item *
 
-L<AnnoCPAN|http://annocpan.org/dist/Bot-IRC-X-Reminder>
+L<GitHub Actions|https://github.com/gryphonshafer/Bot-IRC-X-Reminder/actions>
 
 =item *
 
-L<Travis CI|https://travis-ci.org/gryphonshafer/Bot-IRC-X-Reminder>
-
-=item *
-
-L<Coveralls|https://coveralls.io/r/gryphonshafer/Bot-IRC-X-Reminder>
+L<Codecov|https://codecov.io/gh/gryphonshafer/Bot-IRC-X-Reminder>
 
 =item *
 
@@ -299,9 +290,10 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Gryphon Shafer.
+This software is Copyright (c) 2016-2021 by Gryphon Shafer.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
